@@ -54,6 +54,7 @@ class ContainerTechnology:
     features = {}
 
     def __init__(self):
+
         # If we weren't created with settings, add empty
         if not hasattr(self, "settings"):
             from shpc.main.settings import SettingsBase
@@ -81,15 +82,6 @@ class ContainerTechnology:
         """
         pass
 
-    def module_dir(self, name):
-        """
-        Get the module directory the container references
-        """
-        # If the user provided a tag, tags are converted to folders
-        if ":" in name:
-            name = name.replace(":", os.sep)
-        return os.path.join(self.settings.module_base, name)
-
     def container_dir(self, name):
         """
         Use a custom container directory, otherwise default to module dir.
@@ -134,8 +126,8 @@ class ContainerTechnology:
         """
         module_name = self.guess_tag(module_name)
 
-        # The environment file is stored in the module directory
-        container_dir = self.module_dir(module_name)
+        # This can be the module or container directory
+        container_dir = self.container_dir(module_name)
 
         # Does the user want to see a module file?
         result = os.path.join(container_dir, self.settings.environment_file)
@@ -159,14 +151,18 @@ class ContainerTechnology:
 
         # The config features (defined by the container) determine what we add
         for key, value in config_features.items():
+
             # If the container technology has the feature and is defined in settings
             if key in self.features and key in settings_features:
+
                 # Case 1: the feature is known to the container technology
                 if settings_features[key] in self.features[key]:
+
                     features[key] = self.features[key][settings_features[key]]
 
                 # Case 2: the exact value isn't known, but the feature accepts a string
                 elif type(settings_features[key]) in self.features[key]:
+
                     # Add the feature to be given to the container!
                     value = self.features[key][type(settings_features[key])]
                     if value == "[use-self]":
