@@ -106,18 +106,11 @@ class VersionControl(Provider):
         """
         Retrieve the web url, either pages or (eventually) custom.
         """
-        domain, namespace, repo = self.source_url.split("/")[2:]
-        domain_parts = domain.split("@")[-1].split(".")
-
-        if len(domain_parts) == 2:
-            domain_parts[1] = "io"
-        else:
-            domain_parts.insert(0, "pages")
-
-        return "https://%s.%s/%s/library.json" % (
-            namespace,
-            ".".join(domain_parts),
-            repo,
+        parts = self.source_url.split("/")[3:]
+        return "https://%s.%s.io/%s/library.json" % (
+            parts[0],
+            self.provider_name,
+            "/".join(parts[1:]),
         )
 
     def exists(self, name):
@@ -193,6 +186,7 @@ class VersionControl(Provider):
 
         # This assumes blob/main branch
         for uri, entry in self._cache.items():
+
             # If the user has provided a filter, honor it
             if filter_string and not re.search(filter_string, uri):
                 continue
